/**
 * WordPress dependencies
 */
import { __ } from "@wordpress/i18n";
import { __experimentalBoxControl as BoxControl } from "@wordpress/components";

/**
 * Internal dependencies
 */
import { LabelControl } from "../label-control";

/**
 * Margin control
 *
 * @param {Object} param0
 * @returns
 */
export const MarginControl = ({
  label = __("Margin"),
  boxLabel = "",
  values,
  onChange,
  isRespsonsive,
  isBoldLabel,
  ...otherProps
}) => {
  return (
    <div className="margin-control">
      <LabelControl
        label={label}
        isResponsive={isRespsonsive}
        isBold={isBoldLabel}
      />
      <BoxControl
        label={boxLabel}
        values={values}
        onChange={onChange}
        {...otherProps}
      />
    </div>
  );
};

export const SpacingControl = ({
  label = __("Repsonsive spacing"),
  isRespsonsive,
  paddingValues,
  onChangePadding,
  marginValues,
  onChangeMargin,
  ...otherProps
}) => {
  return (
    <div className="spacing-group-control">
      <LabelControl label={label} isResponsive={isRespsonsive} isBold={true} />
      <BoxControl
        label={__("Padding")}
        values={paddingValues}
        onChange={onChangePadding}
        {...otherProps}
      />
      <BoxControl
        label={__("Margin")}
        inputProps={{ min: -1000 }}
        values={marginValues}
        onChange={onChangeMargin}
        {...otherProps}
      />
    </div>
  );
};
