/**
 * External dependencies
 */

/**
 * WordPress dependencies
 */
import { __ } from "@wordpress/i18n";
import { useState } from "@wordpress/element";
import {
  KeyboardShortcuts,
  ToolbarButton,
  ToolbarGroup,
  Popover,
} from "@wordpress/components";
import { rawShortcut, displayShortcut } from "@wordpress/keycodes";
import { link } from "@wordpress/icons";
import {
  BlockControls,
  __experimentalLinkControl as LinkControl,
} from "@wordpress/block-editor";

/**
 * URL Picker
 *
 * @param {Object}
 * @returns
 */
export function URLPicker({
  value,
  anchorRef,
  onChange,
  onUnlink,
  onRemove,
  isSelected,
}) {
  const [isURLPickerOpen, setIsURLPickerOpen] = useState(false);
  const openLinkControl = () => {
    setIsURLPickerOpen(true);
    return false; // prevents default behaviour for event
  };

  return (
    <>
      <BlockControls>
        <ToolbarGroup>
          <ToolbarButton
            name="link"
            icon={link}
            title={__("Link")}
            shortcut={displayShortcut.primary("k")}
            onClick={openLinkControl}
            isActive={!!value?.url}
          />
        </ToolbarGroup>
      </BlockControls>
      {isSelected && (
        <KeyboardShortcuts
          bindGlobal
          shortcuts={{
            [rawShortcut.primary("k")]: openLinkControl,
            [rawShortcut.primaryShift("k")]: onUnlink,
          }}
        />
      )}
      {isURLPickerOpen && (
        <Popover
          placement="bottom"
          onClose={() => setIsURLPickerOpen(false)}
          anchor={anchorRef?.current}
        >
          <LinkControl
            className="wp-block-navigation-link__inline-link-input"
            value={value}
            onChange={onChange}
            onRemove={onRemove}
          />
        </Popover>
      )}
    </>
  );
}
